summaryrefslogtreecommitdiff
path: root/pkg/domain/entities/play.go
diff options
context:
space:
mode:
Diffstat (limited to 'pkg/domain/entities/play.go')
-rw-r--r--pkg/domain/entities/play.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/pkg/domain/entities/play.go b/pkg/domain/entities/play.go
index ad35dfe25..39234caf8 100644
--- a/pkg/domain/entities/play.go
+++ b/pkg/domain/entities/play.go
@@ -26,8 +26,8 @@ type PlayKubeOptions struct {
Username string
// Password for authenticating against the registry.
Password string
- // Network - name of the CNI network to connect to.
- Network string
+ // Networks - name of the network to connect to.
+ Networks []string
// Quiet - suppress output when pulling images.
Quiet bool
// SignaturePolicy - path to a signature-policy file.